@@ -434,18 +434,42 @@ def test_face_overhang():
     assert face_2.outdoor_shades[0].has_parent
 
 
+def test_face_louvers_by_count():
+    """Test the creation of a louvers_by_count for Face objects."""
+    pts_1 = (Point3D(0, 0, 0), Point3D(0, 0, 3), Point3D(5, 0, 3), Point3D(5, 0, 0))
+    face = Face('RectangleFace', Face3D(pts_1))
+    face.louvers_by_count(3, 0.2, 0.1, 5)
+
+    assert len(face.outdoor_shades) == 3
+    for louver in face.outdoor_shades:
+        assert isinstance(louver, Shade)
+        assert louver.area == 5 * 0.2
+        assert louver.has_parent
+
+
 def test_face_louvers_by_distance_between():
     """Test the creation of a louvers_by_distance_between for Face objects."""
     pts_1 = (Point3D(0, 0, 0), Point3D(0, 0, 3), Point3D(5, 0, 3), Point3D(5, 0, 0))
     face = Face('RectangleFace', Face3D(pts_1))
     face.louvers_by_distance_between(0.5, 0.2, 0.1)
-
     assert len(face.outdoor_shades) == 6
     for louver in face.outdoor_shades:
         assert isinstance(louver, Shade)
         assert louver.area == 5 * 0.2
         assert louver.has_parent
 
+    face.remove_shades()
+    face.louvers_by_distance_between(0.5, 0.2, 0.1, max_count=3)
+    assert len(face.outdoor_shades) == 3
+    for louver in face.outdoor_shades:
+        assert isinstance(louver, Shade)
+        assert louver.area == 5 * 0.2
+        assert louver.has_parent
+
+    face.remove_shades()
+    face.louvers_by_distance_between(0.5, 0.2, 0.1, max_count=10)
+    assert len(face.outdoor_shades) == 6
+
 
 def test_move():
     """Test the Face move method."""
